Added test for ballot and removing HIP_FUNCTION from hipSampleAtomicsTest.cpp -sandeep

[ROCm/hip commit: 2b02fe082f]
Bu işleme şunda yer alıyor:
streamhsa
2016-02-02 14:50:55 +05:30
ebeveyn 114874e5ee
işleme 19d0b8095f
8 değiştirilmiş dosya ile 54 ekleme ve 66 silme
+2 -2
Dosyayı Görüntüle
@@ -190,7 +190,7 @@ int computeGold(int *gpuData, const int len)
return true;
}
__global__ void HIP_FUNCTION(testKernel,int *g_odata)
__global__ void testKernel(hipLaunchParm lp,int *g_odata)
{
// access thread id
const unsigned int tid = hipBlockDim_x * hipBlockIdx_x + hipThreadIdx_x;
@@ -236,7 +236,7 @@ __global__ void HIP_FUNCTION(testKernel,int *g_odata)
// Atomic XOR
atomicXor(&g_odata[10], tid);
}
HIP_FUNCTION_END
int main(int argc, char **argv)
{